==> drools-mvel-7.74.1.Final-sources.jar: org/drools/mvel/dataproviders/ReactiveMVELDataProvider.java <==
/*
 * Copyright (c) 2020. Red Hat, Inc. and/or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.mvel.dataproviders;

import java.util.Iterator;

import org.drools.core.common.InternalWorkingMemory;
import org.drools.core.phreak.ReactiveObject;
import org.drools.core.spi.PropagationContext;
import org.drools.core.spi.Tuple;
import org.drools.mvel.expr.MVELCompilationUnit;

public class ReactiveMVELDataProvider extends MVELDataProvider {

    public ReactiveMVELDataProvider() { }

    public ReactiveMVELDataProvider( MVELCompilationUnit unit, String id) {
        super(unit, id);
    }

    @Override
    public boolean isReactive() {
        return true;
    }

    @Override
    public Iterator getResults( final Tuple tuple,
                                final InternalWorkingMemory wm,
                                final PropagationContext ctx,
                                final Object executionContext ) {
        Object result = evaluate( tuple, wm );
        if (result instanceof ReactiveObject) {
            ( (ReactiveObject) result ).addLeftTuple( tuple );
        }
        return asIterator( result );
    }
}

==> drools-mvel-8.32.0.Final-sources.jar: org/drools/mvel/dataproviders/ReactiveMVELDataProvider.java <==
/*
 * Copyright (c) 2020. Red Hat, Inc. and/or its affiliates.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.mvel.dataproviders;

import java.util.Iterator;

import org.drools.core.common.ReteEvaluator;
import org.drools.core.phreak.ReactiveObject;
import org.drools.core.common.PropagationContext;
import org.drools.core.reteoo.Tuple;
import org.drools.mvel.expr.MVELCompilationUnit;

public class ReactiveMVELDataProvider extends MVELDataProvider {

    public ReactiveMVELDataProvider() { }

    public ReactiveMVELDataProvider( MVELCompilationUnit unit, String id) {
        super(unit, id);
    }

    @Override
    public boolean isReactive() {
        return true;
    }

    @Override
    public Iterator getResults( final Tuple tuple,
                                final ReteEvaluator reteEvaluator,
                                final PropagationContext ctx,
                                final Object executionContext ) {
        Object result = evaluate( tuple, reteEvaluator );
        if (result instanceof ReactiveObject) {
            ( (ReactiveObject) result ).addLeftTuple( tuple );
        }
        return asIterator( result );
    }
}
